==> vee_2.4-6.tar.gz: vee-2.4/src/WIDGET.py <==
# -*- coding: utf-8 -*-
#    Copyright (C) 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import gtk
import gtk.glade

import os, sys

import Conf

GLADEFILE = os.path.join(Conf.DIR_LIBFILE, "vee.glade")

class WIDGET :

	xml = None

	def __init__ (self, WINDOWNAME, \
			ROOTWIDGET=None, handler=dict(), handler_template=dict()) :

		self.xml = gtk.glade.XML(GLADEFILE, WINDOWNAME)

		self.WIDGET_SELF = self.xml.get_widget(WINDOWNAME)
		self.WIDGET_ROOT = ROOTWIDGET

		# assign handler.
		handler["on_quit"] = self.on_quit
		handler["on_close"] = self.on_close
		self.connect_handler(handler, handler_template)

	def connect_handler (self, handler=dict(), handler_template=dict()) :
		__handler = dict()

		if len(handler_template) > 0 :
			[__handler.update({i : eval(j)}) for i, j in handler_template.items()]

			handler.update(__handler)

		if len(handler) > 0 :
			self.xml.signal_autoconnect(handler)

	def on_close (self, widget) :
		self.WIDGET_SELF.destroy()
		return

	def on_quit (self, widget) :
		gtk.main_quit()

def get_widget_from_xml (xmlname, widget_name="") :
	xml = gtk.glade.XML(GLADEFILE, xmlname)
	widget_self = xml.get_widget(xmlname)

	if not widget_name :
		return widget_self
	else :
		return xml.get_widget(widget_name)

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "WIDGET.py"

==> vee_2.5-1.tar.gz: vee-2.5/src/WIDGET.py <==
# -*- coding: utf-8 -*-
#    Copyright (C) 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import gtk
import gtk.glade

import os, sys

import Conf__, i18n
_ = i18n.gettext()

GLADEFILE = os.path.join(Conf__.DIR_LIBFILE, "vee.glade")

class WIDGET :

	xml = None

	def __init__ (self, WINDOWNAME, \
			ROOTWIDGET=None, handler=dict(), handler_template=dict()) :

		self.xml = gtk.glade.XML(GLADEFILE, WINDOWNAME)

		self.WIDGET_SELF = self.xml.get_widget(WINDOWNAME)
		self.WIDGET_ROOT = ROOTWIDGET

		# assign handler.
		handler["on_quit"] = self.on_quit
		handler["on_close"] = self.on_close
		self.connect_handler(handler, handler_template)

	def connect_handler (self, handler=dict(), handler_template=dict()) :
		__handler = dict()

		if len(handler_template) > 0 :
			[__handler.update({i : eval(j)}) for i, j in handler_template.items()]

			handler.update(__handler)

		if len(handler) > 0 :
			self.xml.signal_autoconnect(handler)

	def on_close (self, widget) :
		self.WIDGET_SELF.destroy()
		return

	def on_quit (self, widget) :
		gtk.main_quit()

def get_widget_from_xml (xmlname, widget_name="") :
	xml = gtk.glade.XML(GLADEFILE, xmlname)
	widget_self = xml.get_widget(xmlname)

	if not widget_name :
		return widget_self
	else :
		return xml.get_widget(widget_name)

def set_title (widget, gconf_client, strings, isFilepath=True) :
	__title_format = gconf_client.get_value_by_conf("window-title")

	if not isFilepath :
		__title = "%s : %s" % (strings, _("VEE"))
	else :
		__path_short = os.path.basename(strings)
		__path_full = strings

		__title = \
			__title_format.replace( \
				"%F", __path_full).replace( \
				"%t", __path_short).replace( \
				"%V", _("VEE"))

	widget.set_title(__title)

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "WIDGET.py"
